@@ -15,50 +15,10 @@ has 'socket' => (
     required => 1
 );
 
-#has logger => (
-#    is => 'rw',
-#    isa => 'Object',
-#    lazy => 1,
-#    noGetOpt => 1, 
-#    default => \&_build_logger,
-#);
-        
-#has errorlog => (
-#    is => 'rw',
-#    isa => 'Str',
-#    default => '*STDERR',
-#    trigger => sub { $_[0] -> logger( $_[0] -> _build_logger ) }
-#);
- 
-#has loglevel => (
-#    is => 'rw',
-#    isa => 'Int',
-#    default => '4',
-#    trigger => sub { $_[0] -> logger( $_[0] -> _build_logger ) }
-#);
-
 after 'start' => sub {
     my $self = shift;
 
-    $self -> run if $self -> foreground || $self -> is_daemon;
-};
-
-no Moose::Role;
-    
-#sub _build_logger {
-#    my $self = shift;
-#    Log::Handler -> new (
-#        filename => $self -> errorlog,
-#        mode => 'append',
-#        prefix => "[$0 $$] [<--LEVEL-->] ",
-#        newline => 1,
-#        maxlevel => $self -> loglevel,
-#        debug => $self -> loglevel > 7 ? 1 : 0,
-#    );
-#}
-
-sub run {
-    my($self) = @_;
+    return unless $self -> foreground || $self -> is_daemon;
 
     my $env = { };
 
@@ -111,7 +71,7 @@ sub run {
 
         print 'Status: ' . $resp -> as_string;
     }
-}
+};
 
 1;
 
@@ -151,23 +111,12 @@ extended to run the FastCGI request loop in the daemonized process.
 
 This is the UNIX socket on which the server listens.
 
-=item errorlog
-
-This is the filename (or one of *STDOUT, *STDERR) where errors are logged.
-
-=item loglevel
-
-The severity threshold above which errors are logged.  See L<Log::Hander>
-for the log levels.  Any log level above 7 will turn on debugging.
-
 =back
 
 =head1 METHODS
 
 =over 4
 
-=item run
-
 =item start
 
 =back
